import { ElementRef, EventEmitter, OnDestroy, QueryList } from '@angular/core';
import { BehaviorSubject, Observable, Subject } from 'rxjs';
import { BsCalendarMonthService } from '../../../../services/calendar-month/calendar-month.service';
import { DragOperation } from '../../interfaces/drag-operation';
import { PreviewEvent } from '../../interfaces/preview-event';
import { SchedulerEvent } from '../../interfaces/scheduler-event';
import { SchedulerEventPart } from '../../interfaces/scheduler-event-part';
import { SchedulerEventWithParts } from '../../interfaces/scheduler-event-with-parts';
import { TimeSlot } from '../../interfaces/time-slot';
import { BsTimelineService } from '../../services/timeline/timeline.service';
import * as i0 from "@angular/core";
export declare class BsSchedulerComponent implements OnDestroy {
    private calendarMonthService;
    private timelineService;
    constructor(calendarMonthService: BsCalendarMonthService, timelineService: BsTimelineService);
    events$: BehaviorSubject<SchedulerEvent[]>;
    eventParts$: Observable<SchedulerEventWithParts[]>;
    eventPartsForThisWeek$: Observable<SchedulerEventPart[]>;
    timelinedEventPartsForThisWeek$: Observable<{
        total: number;
        parts: {
            part: SchedulerEventPart;
            index: number;
        }[];
    }>;
    previewEvent$: BehaviorSubject<PreviewEvent | null>;
    previewEventParts$: Observable<SchedulerEventWithParts | null>;
    previewEventPartsForThisWeek$: Observable<SchedulerEventPart[]>;
    currentWeek$: BehaviorSubject<Date>;
    daysOfWeek$: Observable<Date[]>;
    daysOfWeekWithTimestamps$: Observable<{
        start: number;
        end: number;
    }>;
    timeSlotDuration$: BehaviorSubject<number>;
    timeSlots$: BehaviorSubject<TimeSlot[][]>;
    mouseState$: BehaviorSubject<boolean>;
    hoveredTimeSlot$: BehaviorSubject<TimeSlot | null>;
    hoveredEvent$: BehaviorSubject<SchedulerEvent | null>;
    destroyed$: Subject<unknown>;
    timeSlotElements: QueryList<ElementRef<HTMLDivElement>>;
    unitHeight$: BehaviorSubject<number>;
    unitHeightChange: EventEmitter<number>;
    get unitHeight(): number;
    set unitHeight(value: number);
    maxInnerHeight: number | null;
    private addDays;
    onPreviousWeek(): void;
    onNextWeek(): void;
    onHoverEvent(ev: SchedulerEvent | null): void;
    onLeaveEvent(ev: SchedulerEvent | null): void;
    operation: DragOperation | null;
    dragStartTimeslot: TimeSlot | null;
    onCreateEvent(ev: MouseEvent, slot: TimeSlot): void;
    randomColor(): string;
    randomChannel(brightness: number): string;
    onStartDragEvent(eventPart: SchedulerEventPart, ev: MouseEvent): void;
    onStartResizeEvent(event: SchedulerEvent | null, position: 'top' | 'bottom'): void;
    private getHoveredTimeslot;
    onMousemove(ev: MouseEvent): void;
    onMouseUp(ev: MouseEvent): void;
    ngOnDestroy(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<BsSchedulerComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<BsSchedulerComponent, "bs-scheduler", never, { "unitHeight": "unitHeight"; "maxInnerHeight": "maxInnerHeight"; }, { "unitHeightChange": "unitHeightChange"; }, never, never>;
}
